<?php
/**
 * This file is responsible for geoadvanced template loader and db connector
 */
require './configs/constants.php';
require './library/iplocation/iplocation-finder.php';
require './geoadvanced_db.php';

 class GeoAdvanced_Downloader {
    private $DB_Obj;
    public function __construct() {
        $this->DB_Obj = new GeoAdvanced_Db(DB_HOST, DB_USERNAME, DB_PASSWORD, DB_NAME, DB_PORT);

    }

    public function  template_loader() {
        session_start();
        $ip = $this->get_client_ip();
  
        $details = $this->get_client_ip_details($ip);
        $ip_details['Your IP'] = $ip;
       
        $ip_details = array_merge($ip_details, $details);
        $errors = $this->validate_data($ip_details);
        $data_inserted = false;
        if(empty($errors) && isset($_POST['captcha'])) {
           $data_inserted =  $this->insert_data($ip_details);
        }
        
         if($data_inserted) {
            header('Location: https://geosuite3dcom.ipage.com/downloads/GeoSuite2.2Demo_Setup.exe');
        }

        include './geoadvanced_template.php';
       
    }

    public function validate_data() {
        $errors = [];
        if(!isset($_POST['captcha'])) {
            return $errors;
        }
        if (strtolower($_SESSION['secure']) !== strtolower($_POST['captcha'])) {
            $errors['captcha'] = 'Captcha Error';
        }
        return $errors;
    }

    public function insert_data($ip_details) {
        if(!isset($_POST['name'])){
            return false;
        }
        $data = filter_var_array($_POST);
        return $this->DB_Obj->insert_user_data($data, $ip_details);

    }


    public function get_client_ip(){
        $server_ip_keys =  array(
                    'HTTP_CLIENT_IP',
                    'HTTP_X_FORWARDED',
                    'HTTP_FORWARDED_FOR',
                    'HTTP_FORWARDED',
                    'HTTP_X_FORWARDED',
                    'REMOTE_ADDR'
        );

        foreach($server_ip_keys as $key) {
            if (isset($_SERVER[$key])) {
            
                return $_SERVER[$key];
            }
        }
        foreach (explode(",",$_SERVER["HTTP_X_FORWARDED_FOR"]) as $ip) {
            if (validip(trim($ip))) {
                return $ip;
            }
        }
    }

    public function get_client_ip_details($ip){
        $ip_details = array(
                'Country' => '', 
                'State' => '', 
                'City' => '',
                'Org' => ''
        );
        
        if (empty($ip)) {
            return $ip_details;
        }

        $ipLite = new ip2location_lite;
        $ipLite->setKey(IP_LOCATION_API_KEY);
        $locations = $ipLite->getCity($ip);
        $errors = $ipLite->getError();
        $org_details = $this->get_org_details($ip);
        if (empty($errors)) {
            $ip_details['Country'] = $locations['countryName'];
            $ip_details['State'] = $locations['regionName'];
            $ip_details['City'] = $locations['cityName'];
            $ip_details['Org'] = $org_details;
        }

        return $ip_details;
        
    }

    function get_org_details($ip) {
        
        $ch = curl_init();

        // set URL and other appropriate options
        curl_setopt($ch, CURLOPT_URL, 'http://whois.arin.net/rest/ip/' . $ip);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Accept: application/json'));
        
        // execute
        $returnValue = curl_exec($ch);
        
        // close cURL resource, and free up system resources
        curl_close($ch);
        if ( false == $returnValue ) {
            return '';
        }    
        $result = json_decode($returnValue);
        return $result->net->orgRef->{'@name'};
    }

    
 }

 $GeoAdvanced_Downloader = new GeoAdvanced_Downloader();

 $GeoAdvanced_Downloader->template_loader();
